@@ -5,7 +5,7 @@
 #' @param x Character, Character or list. One or more paths to EarthExplorer export files.
 #' @return data.frame
 #' @details 
-#' The \href{http://earthexplorer.usgs.gov/}{EarthExplorer} CSV file can be produced from the search results page. Above the results click on 'export results' and select 'comma (,) delimited'.
+#' The \href{https://earthexplorer.usgs.gov/}{EarthExplorer} CSV file can be produced from the search results page. Above the results click on 'export results' and select 'comma (,) delimited'.
 #' 
 #' Note that only a subset of columns is imported which was deemed interesting. Please contact the maintainer if you think an omited column should be included. 
 #' 
@@ -41,7 +41,7 @@ readEE <- function(x) {
                 df <- df[,allLScats[inter]]
                 df[,allLScats[!inter]] <- NA
                 df <- df[, allLScats]
-                df$Date <- as.POSIXct(df$Date.Acquired, "%Y/%m/%d")
+                df$Date <- as.POSIXct(df$Date.Acquired, format = "%Y/%m/%d")
                 df$Doy  <- as.numeric(format(df$Date, format = "%j"))
                 df$Year <- as.numeric(format(df$Date, format = "%Y"))
                 df$Satellite <- paste0("LS", substr(df$Landsat.Scene.Identifier, 3, 3))
